#ifndef PVO_HH_
#define PVO_HH_
#include <iostream>

namespace PVO
{

  /** Version number of PVO programs */
  const std::string PVO_VERSION = "1.0";
  
  const std::string PVOCONVERT = "pvoconvert";
  const std::string PVOSUMMARY = "pvosummary";
  const std::string PVOCONESEARCH = "pvoconesearch";
  const std::string PVOTAPESUMMARY = "pvotapesummary";

  /** Standard NULL value for strings. */
  const std::string nullString = "NULL";

  /** Standard NULL value for floats. */
  const float       nullFloat = -9999.;

  /** Standard NULL value for ints. */
  const int         nullInt = -9999;

  /** Help text for pvoconvert -h */
  const std::string pvoconvert_usage_text = 
"Usage: pvoconvert [options] <survey file(s)> ...\n\
  Running options:\n\
  -D <dir>          Run pvoconvert on all files in the stated directory.\n\
  --directory <dir>\n\
                     No <survey file> needs to be given in this case.\n\
  -H                Use the PH (High Latitude) Survey settings, rather than\n\
  --highlat          those for the PM/Multibeam Survey\n\
  -V                Verbose mode for error/warning messages.\n\
  --verbose\n\
\n\
  Other options:\n\
  -h                Display this help page.\n\
  --help\n\
  -v                Display the version number.\n\
  --version\n\
---------\n\n\
 PVOConvert converts pulsar survey data into PSRFITS format.\n\
 It can distinguish between the 70cm data and 21cm Multibeam data, but to\n\
  specify particular data as coming from the High Latitude survey rather\n\
  than the standard Multibeam survey, use the -h option.\n\
 Note that more than one input file can be given.\n\
 Output files will be encoded according to the survey type and date & time\n\
  of observation.\n";
  /** Brief help text for pvoconvert -h */
  const std::string pvoconvert_usage_text_short = 
"Usage: pvoconvert [options] <survey file(s)> ...\n\
  Running options:\n\
  -D <dir>          Run pvoconvert on all files in the stated directory.\n\
  --directory <dir>\n\
                     No <survey file> needs to be given in this case.\n\
  -H                Use the PH (High Latitude) Survey settings, rather than\n\
  --highlat          those for the PM/Multibeam Survey\n\
  -V                Verbose mode for error/warning messages.\n\
  --verbose\n\
\n\
  Other options:\n\
  -h                Display the help page.\n\
  --help\n\
  -v                Display the version number.\n\
  --version\n";

  /** Help text for pvosummary -h */
  const std::string pvosummary_usage_text = 
"Usage:\n\
  1. pvosummary [options]\n\
  2. pvosummary [options] <FILE>\n\
---------\n\
 pvosummary  prints out some basic metadata for either all FITS files in the\n\
  current directory (example 1), or a single FITS file (example 2).\n\
 The parameters printed out are:\n\
   FILENAME, SRC_NAME, RAJ, DECJ, BEAM FWHM, OBSFREQ, SCANLEN, DATE-OBS\n\
 If a keyword is not present, "+nullString+" is printed.\n\
 The full set of parameters can be written in csv format to a file using the\n\
   -c or --csv option.\n\
 The list of parameters can be obtained by using the -p option.\n\
 FITS files are assumed to have suffixes of .fits or .rf\n\n\
 Running options:\n\
 -c <file>    Write all parameters in csv format to the specified file.\n\
 --csv <file>\n\
 -p           List all parameters\n\
 -q           Quiet mode -- nothing printed to screen\n\
               (used in conjunction with -c)\n\
 -V           Verbose mode for error/warning messages.\n\
 --verbose\n\
  Other options:\n\
 -h           Print this help message.\n\
 --help \n\
 -v           Print the version number.\n\
 --version \n\
---------\n\
";
  /** Brief help text for pvosummary -h */
  const std::string pvosummary_usage_text_short = 
"Usage:\n\
  1. pvosummary [options]\n\
  2. pvosummary [options] <FILE>\n\
 Running options:\n\
 -c <file>    Write all parameters in csv format to the specified file.\n\
 --csv <file>\n\
 -p           List all parameters\n\
 -q           Quiet mode -- nothing printed to screen\n\
               (used in conjunction with -c)\n\
 -v           Verbose mode for error/warning messages.\n\
 --verbose\n\
 Other options:\n\
 -h           Print a help message.\n\
 --help\n\
 -v           Print the version number.\n\
 --version \n";

  /** Help text for pvotapesummary -h */
  const std::string pvotapesummary_usage_text = 
"Usage:\n\
  1. pvotapesummary [FILE] ...\n\
  2. pvotapesummary -d <DIR>\n\
---------\n\
 pvotapesummary  prints out some basic metadata for either all tape survey files\n\
  provided as arguments (#1), or all files in the specified directory (#2).\n\
 You can optionally specify individual files: the alternative is to examine each\n\
  file in the directory.\n\
 The metadata is taken just from the first block in the tape file.\n\
 The parameters printed out are:\n\
   FILENAME, RA, DEC, OBSFREQ, SCANLEN, MOVE, DATE-OBS\n\
---------\n\
";

  /** Help text for pvoconesearch -h */
  const std::string pvoconesearch_usage_text = 
"Usage:\n\
  1. pvoconesearch ra dec radius\n\
  2. pvoconesearch -h\n\
---------\n\
  1. Prints RA, DEC, BEAM FWHM, OBSFREQ, DATE-OBS, OFFSET for all FITS files\n\
     that lie within \"radius\" of the position given by ra, dec.\n\
     OFFSET is angular offset from query position.\n\
  2. Prints this help information.\n\n\
 The valid files are listed in order of increasing angular separation from\n\
  the query position.\n\
 The RA and DEC can be in the form hh:mm:ss.ss etc or in decimal degrees.\n\
 The search radius is in degrees. The beam size is also taken into account,\n\
  so the effective search radius becomes (radius + 0.5*beamFWHM).\n\
 Note that if a keyword is not present, NULL is printed.\n\
 FITS files are assumed to have suffixes of .fits or .rf\n";
  /** Brief help text for pvoconesearch -h */
  const std::string pvoconesearch_usage_text_short = 
"Usage:\n\
  1. pvoconesearch ra dec radius\n\
  2. pvoconesearch -h\n";



}

#endif // PVO_HH_
